@@ -66,7 +66,11 @@ class FWConfig(object):
 
         self.CONFIG_FILE_DIR = '.'  # directory containing config files (if not individually set)
 
-        self.AVOID_MANY_QSTATS = True  # try to avoid calling qstat many times
+        self.QSTAT_FREQUENCY = 50  # set this higher to avoid qstats, lower to alwas
+
+        self.ALWAYS_CREATE_NEW_BLOCK = False  # always create new block on queue launcher call
+
+        self.TEMPLATE_DIR = None  # default template dir for TemplateWriterTask
 
         self.override_user_settings()
 
@@ -87,7 +91,7 @@ class FWConfig(object):
                         self.USER_PACKAGES.extend(v)
                     elif key == 'ECHO_TEST':
                         print v
-                    elif not getattr(self, key, None):
+                    elif not hasattr(self, key):
                         raise ValueError(
                             'Invalid FW_config file has unknown parameter: {}'.format(
                                 key))
